#[cfg(test)]
mod test {
    use flate2::Compression;
    use httpmock::Method::GET;
    use httpmock::MockServer;

    #[test]
    fn example_test() {
        // Start a local mock server for exclusive use by this test function.
        let mock_server = MockServer::start();

        let json_response = serde_json::json!({
            "crate": {
                "id": "cargo-raze",
                "name": "cargo-raze",
                "versions": [
                    283716
                ],
            },
            "versions": [
                {
                    "id": 283716,
                    "crate": "cargo-raze",
                    "num": "0.5.0",
                    "dl_path": "/api/v1/crates/cargo-raze/0.5.0/download",
                }
            ],
        });

        // Create archive contents
        let dir = tempfile::tempdir().unwrap();
        let tar_path = dir.as_ref().join("archive.tar.gz");
        {
            std::fs::create_dir_all(dir.as_ref().join("archive")).unwrap();
            std::fs::File::create(dir.as_ref().join("archive/test")).unwrap();
    
            let tar_path = dir.as_ref().join("archive.tar.gz");
            let tar_gz: std::fs::File = std::fs::File::create(&tar_path).unwrap();
            let enc = flate2::write::GzEncoder::new(tar_gz, Compression::default());
            let mut tar = tar::Builder::new(enc);
            tar.append_dir_all(        "cargo-raze-0.5.0", dir.as_ref().join("archive")).unwrap();
        }

        mock_server.mock(|when, then| {
            when.method(GET)
                .path("/api/v1/crates/cargo-raze");
            then.status(200)
                .json_body(json_response);
        });

        mock_server.mock(|when, then| {
            when.method(GET)
                .path("/api/v1/crates/cargo-raze/0.5.0/download");
            then.status(200)
                .header("content-type", "application/x-tar")
                .body_from_file(tar_path.display().to_string());
        });

        let url = mock_server.url("");

        let mut cloner = cargo_clone::Cloner::new();
        cloner.set_registry_url(url);
        cloner.clone(
            cargo_clone::CloneMethodKind::Crate,
            "cargo-raze",
            Some("0.5.0"),
            &Vec::new(),
        ).unwrap();
    }
}

fn main() {}
